@@ -1,12 +1,15 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """Remove green color from selected objects"""
 
 import inkex
 
+
 class RemoveGreen(inkex.ColorExtension):
     """Remove green color from selected objects"""
+
     def modify_color(self, name, color):
         return inkex.Color([color.red, 0, color.blue])
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     RemoveGreen().run()
